==> spoofer-0.6.tar.gz: spoofer-0.6/messages.h <==
/****************************************************************************
   Program:     $Id: messages.h,v 1.14 2008/12/18 16:02:40 rbeverly Exp $
   Author:      Rob Beverly <rbeverly at csail.mit.edu>
   Date:        $Date: 2008/12/18 16:02:40 $
   Description: Define control message types
****************************************************************************/

enum msg_types {DEFAULT, HELLO, PROBE_REQ, REPORT, TRACE, ERR, DONE};
char *printCharStr(unsigned char *str, int len);

/* Test probe format */
#pragma pack(2)
#define SEQNOSIZE 14
#define HMACSIZE  16
typedef struct test {
    uint32_t src_addr;
    uint32_t dst_addr;
    unsigned char seqno[SEQNOSIZE];
    unsigned char hmac[HMACSIZE];
} test_t;

typedef struct probe_hdr {
    uint16_t ver;
    uint16_t unused;
} probe_hdr_t;

typedef struct probe {
    probe_hdr_t hdr;
    test_t tst;
} probe_t;
#define PROBESIZE sizeof(probe_t)
#define PAYLOADSIZE (sizeof(probe_t) - HMACSIZE)

typedef struct spoof_msg {
    uint8_t ver;
    uint8_t type;
    uint8_t flag;  /* 0 = request, 1 = response */
    uint8_t ack;   /* 0 = negative, 1 = positive */
    uint16_t len;
    uint16_t unused;
} spoof_msg_t;

typedef struct hello_msg {
    uint32_t ip;
    uint8_t dist;
    uint8_t oslen;
    uint16_t unused;  
    uint32_t sessionid;
} hello_msg_t;

typedef struct report_msg {
    uint32_t src_ip;
    uint32_t dst_ip;
    uint8_t seqlen;
    uint8_t ack;	/* 0 = sendtofail, 1 = ok */
    uint16_t unused;
} report_msg_t;

typedef struct addr_list {
    uint16_t size;
    uint16_t unused;
} addr_list_t;

#pragma pack()

==> spoofer-0.7.3.tar.gz: spoofer-0.7.3/messages.h <==
/****************************************************************************
   Program:     $Id: messages.h 497 2009-03-08 17:57:15Z rbeverly $
   Author:      Rob Beverly <rbeverly at csail.mit.edu>
   Date:        $Date: 2009-03-08 13:57:15 -0400 (Sun, 08 Mar 2009) $
   Description: Define control message types
****************************************************************************/

enum msg_types {DEFAULT, HELLO, PROBE_REQ, REPORT, TRACE, ERR, DONE, TRACEFILT};
char *printCharStr(unsigned char *str, int len);

/* Test probe format */
#pragma pack(2)
#define SEQNOSIZE 14
#define HMACSIZE  16
typedef struct test {
    uint32_t ts;
    uint32_t src_addr;
    uint32_t dst_addr;
    unsigned char seqno[SEQNOSIZE];
    unsigned char hmac[HMACSIZE];
} test_t;

typedef struct probe_hdr {
    uint16_t ver;
    uint16_t unused;
} probe_hdr_t;

typedef struct probe {
    probe_hdr_t hdr;
    test_t tst;
} probe_t;
#define PROBESIZE sizeof(probe_t)
#define PAYLOADSIZE (sizeof(probe_t) - HMACSIZE)

typedef struct spoof_msg {
    uint8_t ver;
    uint8_t type;
    uint8_t flag;  /* 0 = request, 1 = response */
    uint8_t ack;   /* 0 = negative, 1 = positive */
    uint16_t len;
    uint16_t unused;
} spoof_msg_t;

typedef struct hello_msg {
    uint32_t ip;
    uint8_t dist;
    uint8_t oslen;
    uint16_t unused;  
    uint32_t sessionid;
} hello_msg_t;

typedef struct report_msg {
    uint32_t src_ip;
    uint32_t dst_ip;
    uint8_t seqlen;
    uint8_t ack;	/* 0 = sendtofail, 1 = ok, 2 = host-detected NAT */
    uint16_t unused;
} report_msg_t;

typedef struct addr_list {
    uint16_t size;
    uint16_t unused;
} addr_list_t;

typedef struct tracefilter_test {
    uint8_t dist;
    uint8_t ver;
    uint16_t unused;  
    uint32_t dst_ip;
} tracefilter_test_t;

#pragma pack()
